@@ -35,7 +35,7 @@ class Query(object):
             "Accept": "application/json",
             "Authorization": "token {token}".format(token=self._token),
             "X-API-Version": "20151130",
-            "User-Agent": "Python API 1.93 / {local_version}".format(local_version=platform.python_version())
+            "User-Agent": "Python API 1.94 / {local_version}".format(local_version=platform.python_version())
         }
         self._dataset_id = None
         self._tickers = []
@@ -276,7 +276,7 @@ class Query(object):
         return json.loads(response.text).get('queries', {}).get(query, [])
 
     # Return data
-    def get_data(self, dataset_id, start=None, limit=None):
+    def get_data(self, dataset_id, start=None, limit=None, except_on_truncate=False):
         if not dataset_id:
             return {}
         if self._start < 1:
@@ -322,6 +322,8 @@ class Query(object):
                     "limit": self._limit
                 }
             )
+            if except_on_truncate is True and response.headers['X-Truncated'] == 'true':
+                raise Exception('Data truncated')
             if response.status_code == self.OK:
                 is_created = True
                 break
